# Landscape Plans

So that we can track or progress at both planning and landscaping we will record our goals as well as observations made while working on this project.  We would like to claim that we have reached various milestones as we improve our plans and finish landscape changes.  Few problems have been identified and our project scope suffers.  With limited insight into what is required to manage this project we have opted to hire professionals to flush out potential problems and reign in the scope so that we have attainable goals. 

What follows is ideas and completed tasks, organized so that one can familiarize themselves with parts of the project.  This document serves as the central repository for defining and tracking goals. [?](#instructions)

## Important

### goals
* [Onboarding Questionnaire](#general-questions)
* [Some Notes](#some-other-notes)
* [USDA Plant Hardiness Reference For 5a](#zone-5a-reference)

### landscape
* [Topography](#topography)
* [Basic Overhead View](#overhead-view)

### soil stuff
* [Soil Settle Test](#soil-settle-test)
* [Soggy Lawn Issue](#soggy-lawn-issue)
* [Pictures of Soil](#pictures-of-soil)
* [Squeeze Test](#squeeze-test)
* [Nutrient Testing](#acidity-nitrogen-phosorous-test)

## Wants
* [Composting](#composting)
* [Native Plants](#native-plants)
* [Garden Beds](#garden-beds)
* [Retaining Walls](#retaining-walls)
* [Vegetable Garden](#vegetable-garden)
* [Chinese Style Greenhouses](#chinese-style-greenhouses)
* [Rainwater Harvesting](#rainwater-harvesting)
* [Rain Garden](#riprap-infiltration-pit-rain-garden)
* [Worms](#worms)
* [Arborist](#arborist)

# Completed Projects
## topography
![topography preview](images/topography.png)

[3d render](3d-topograph.html) for a better sense of topography

## zone 5a reference

### Temperature 

Each zone subset is separated by 5°F. For Zone 5, the temperature range is:
* Zone 5a: This subzone has a minimum average temperature of -15° to -20° F

The temperatures can drop below the average minimums due to unusual weather patterns.

### Growing Season
The majority of vegetables can be grown in Zone 5. This zone is considered a medium growing season, but is shorter than higher numbered zones. Many vegetables can reach maturation before the first frost. The growing season lasts from late spring to mid-fall, with the last frost date falling in early May and the first frost occurring around mid-October
*  The last frost date is typically May 15.
*  The first frost date is October 15.

It's important that Zone 5 growers keep up with temperature changes, especially frost warnings. A frost date app is an excellent gardening tool for short growing seasons, so you receive information for your zip code about frost warnings.
*  You can increase the growing timeframe with such things as raised beds that keep the soil warmer than field crops. You can also use hoop tunnels over raised beds/rows or plant inside cold frames.
 
### Growing Tips
*  Some of Zone 5 fruit tree varieties include Harrow Delight pear, Warren plum, Pink Lady apple and native Pawpaw trees.
*  Vegetables include beans, beets, corn, cucumbers, tomatoes and most vegetables.
*  Nut trees ideal for Zone 5 include walnuts, chestnuts, hazelnut and hickory nuts.
*  Start seeds indoors at least six weeks before the last frost date or sooner.
*  Check the zone and days on vegetable, herb and flower seed packets(link to free seed sources) and plant containers. The days represent the maturation time from seed sowing to harvesting or flower blooming. Use this information to plan your garden.

### List of USDA Zone 5 Plants
Zone 5 experiences cold temperatures and short growing seasons, with few year-round plants able to survive the freezing winter temperatures. However, many cold-hardy plants thrive in this region’s mild summers, including:

1.  Aster: Perennial aster flowers commonly sprout lilac or purple daisy-like flower heads in the fall. No matter which flower color you prefer, planting aster seeds is ideal for keeping your garden vibrant and eye-catching in the late summer through the fall.
Bee balm: Bee balm––also known as monarda plant, bergamot, horsemint, or Oswego tea––is a member of the Lamiaceae or mint family. Bee balm has square stems that appear in red, lavender, white, pink, or purple shades, and its leaves are often blue-green. This perennial flowering herb originated in the cool-weather prairie and woodland areas of North America.

2.  Beets: Beets are fast-growing, cool-season crops that are simple to grow and harvest in your vegetable garden. To sow beet seeds, wait until the last frost and plant them in early spring. Although susceptible to wireworms, root maggots, and cutworms, beets are generally hardy, able to withstand a cooler climate and partial shade, and ready to harvest in the fall.

3.  Butternut squash: Pear-shaped butternut squash has orange-yellow sweet flesh, making it the primary ingredient in many stir-fries and soups. This sweet winter squash variety is cold-hardy and a great culinary staple to grow in your vegetable garden.

4.  Catmint: Catmint is the common name for Nepeta, an aromatic perennial plant in the mint family. Drought-tolerant and deer-resistant, catmint is easy to grow and maintain. This herb produces long-blooming flowers that start to blossom in late spring and last through the summer. In addition to its multicolored blooms, the catmint plant has silvery green leaves with a potent aroma that cats love.

5.  Chives: Chives (Allium schoenoprasum) are a thin, grass-like member of the allium family, which includes garlic, scallions, shallots, and leeks. Chives have a subtle oniony flavor and are available for sale at most grocery stores and farmers’ markets. These plants also produce edible purple flowers called chive blossoms, which growers typically trim during harvest.

6.  Coneflowers: Coneflowers are any of three genera of the daisy, aster, and sunflower (Asteraceae) family: Echinacea, Ratibida, and Rudbeckia (also known as black-eyed Susans). The name “coneflower” refers to the flower’s cone-shaped center, or disk. Coneflowers are perfect for home gardens because they are drought- and heat-tolerant and can grow in frigid temperatures. They also attract pollinators such as butterflies, hummingbirds, and bees.

7.  Coral bells: Coral bells belong to the Heuchera genus of perennial flowering plants from North America. Coral bells have thick, sturdy flower stems; variegated, lobed leaves; and many small, colorful red, purple, white, or pink flowers. Hummingbirds, butterflies, and other insects flock to these plants to consume their sweet nectar.

8.  Coreopsis: The coreopsis species, also known as tickseed, is a yellow flower with green foliage that blooms all summer long. This yellow flowering plant offers natural birdseed for chickadees, finches, and sparrows, while its flowers entice hummingbirds, butterflies, and ladybugs. In addition to their visual appeal, coreopsis flowers tolerate heat, humidity, and droughts. The plant is both rabbit- and deer-resistant and grows well in shallow, rocky soil.
Geranium: Geraniums bloom showy bright pink (and sometimes dark red) symmetrical flowers. Growers can use them as garden bedding plants, flower bed specimens, or houseplants. During the winter months, outdoor-grown geraniums remain alive underground via creeping rhizomes that sprout again in the spring in Zone 5. Dwarf cultivars and varieties of geraniums will grow up to eight inches tall, while other species will reach three feet in height with the right growing conditions.

9.  Hostas: If you’re looking for a low-maintenance foliage plant to provide your garden with some ornamental ground cover, hostas are a great option. Hosta leaves usually come in broad-leaf shapes, from pointed, oval leaves to heart-shaped to circular ones. In addition to their waxy, bright green leaves, hostas bloom showy flowers in pink, lilac, and lavender colors.

10.  Hydrangea: Panicle hydrangeas (H. paniculata) bloom in the late summer in colder climates like Zone 5. Deciduous hydrangeas can grow up to fifteen feet tall without pruning. The Hydrangea paniculata thrives in direct sunlight and forms cone-shaped flower heads.

11.  Pacific Giant delphinium: With flower spikes in violet, pink, and several shades of blue, this heirloom variety of the perennial delphinium plant makes a gorgeous cut flower for decorative use. Pacific Giants are mildew-resistant and deer-resistant, and they attract hummingbirds to your garden.

12.  Phlox: With more than sixty-seven species, the perennial flower phlox comes in various sizes and colors. Phlox is a cold-hardy plant with a long flowering season. Common flower colors include lavender, pink, orange, white, and red. Phlox also have bicolor blooms, featuring an “eye” in the center of each flower, or a color shade distinct from the outer petals.

13.  Reblooming daylily: Daylilies (Hemerocallis) are low-maintenance perennial plants. Daylily flowers bloom during the day, wither by night, and emerge again in the morning. Typically, daylily flowers have three petals and three sepals—leaf-like petals that protect the flower buds. The blossoms can grow anywhere from three to fifteen inches wide and come in an extensive range of colors and fragrances.

14.  Russian sage: Russian sage (Perovskia atriplicifolia) is a low-maintenance, bushy perennial plant that blooms small violet flowers throughout the summer. It is not a true sage (or salvia) plant but a member of the mint family (Lamiaceae). Its aromatic flowers attract many pollinators like honeybees, hummingbirds, and butterflies. Drought-tolerant Russian sage is a popular xeriscaping specimen—which is a style of landscaping that requires little to no water—making it a perfect addition to a rock garden alongside succulents and other ornamental grasses.
Rhubarb: Rhubarb plants (Rheum rhabarbarum)—with their large leaves and long, colorful stalks—were initially classified as vegetables. However, the USDA began recognizing rhubarb as a fruit in the twentieth century, thanks in part to how the slightly bitter stalk serves as an ideal template for all manner of fruity desserts. Rhubarb is a popular summer garden vegetable in Zone 5.

15.  Sedum: Sedum, also called stonecrop, is a fleshy-stemmed perennial plant with colorful, star-shaped flowers and succulent leaves. Sedum plants vary in size from three-inch-tall low-growers to three-foot-tall upright specimens. Most sedum plants bloom red, yellow, or white flowers in late summer and fall. Sedum nectar attracts all types of pollinators, including hummingbirds.

16.  Yarrow: Yarrow (Achillea millefolium) is an herbaceous perennial with tall stems, fern-like leaves, and bundles of tiny flower heads growing in circular blooms. Yarrow plants have a long bloom time lasting from early spring to late fall. The flowerheads come in white, red, pink, or bright yellow, bringing vibrant blooms to a garden, flower pot, or lawn.

## soil settle test
![soil settle test](images/collage-small.png)

[full size](images/soil-settle-test.png)

### method
Add a hundfull of soilto a transaprent container, add water, shake well and then leave to settle for 12 hours.
*  clay and silty soils will leave cloudy water with a layer of particles at the bottom
*  sandy soils will leave the water mostly clear and most of the particles will fall, forming a layer on the base of the container
*  peaty soils will see many particles floating on the surface; the water will be slighty cloudy with a thin layer at the bottom
*  soils that are chalky will leave a layer of whitish, grit-like fragments on the bottom of the container and the water will be a shade of pale gray
*  if the water is quite clear with layered particles on the bottom of the container with the finest particle at the top -- this soil is likely to be loamy one

## pictures of soil
[![using shovel to dig hole](images/thumbs/shovel-hole.jpg)](images/shovel-hole.jpg)
[![inside a hole in ground](images/thumbs/hole.jpg)](images/hole.jpg)
[![lump of soil squeezed together](images/thumbs/lump-test.jpg)](images/lump-test.jpg)
[![soil broken apart](images/thumbs/break-apart.jpg)](images/break-apart.jpg)
# In Pprogress

## general questions
Questions that landscapers have when starting a project, better define the scope, Questions are broad it is sometimes hard to know what they are asking

1.  What are the needs and aspirations for this garden?

> besides small projects, these are the bigger longer lasting goals:
> *  replace lawn with native plants
> *  manage stormwater
> *  200-400sqft of vegetable garden

>>   *What are our interests?  Narrow down what our goals are*

2.  Who are the users of this garden?  Are there going to be special needs for the users of the garden?

> Mostly just us, we do have occasional wildlife, a rabbit lives under one of the landscape bushes.  We talked about some possibilities like old people and wildlife.  Right now those do not seem important.  Maybe deer would be a nuisance but right now they are pretty cool.  We will be living here until we are old so that might become a concern. 

>> *previous notes; are these possibilities?*
>> *Old people*
>> *Are there ADA requirements, local requirements, old people, etc (move to question 8 maybe not)*
>> *Deer, rabbits, wildlife*

3.  What activities will happen in my front yard/ backyard?  *Are we planning on hosting parties, hang out and laze in the sun, yoga, martial arts, what do you see yourself doing in your yard, what does the space need to accommodate for?  Do you want a place for your kids to hang out.  Do you want a path to walk people around the garden?  Do you want the family over weekly for BBQ.*

> I think we will eventually want a small front porch for having tea and toast in the morning.  Very small, just enough for two chairs.  The front yard is mostly for looking, we do not have plans for it.  We have a large deciduous tree on the city's road verge that provides shade during the summer.
> An outdoor kitchen on the back patio is in the plan.
> The backyard is meant to host the vegetable garden
> Side yards and the front yard may hold functional garden elements
> Behind the garage and adjacent to the fence may be the composting area
> If we do have parties in the backyard they will most likely be confined to the existing patio
> The front yard needs to allow for snow management near borders where there may be pedestrian traffic

4.  What level of maintenance is manageable?  *When you are working on the garden yes a bunch of time is put it.  Wants to know how much maintenance is needed.  How much free time do we have.  When you are designing your garden - choose things that will help make maintenance better versus if you want to keep yourself busy working on your garden.
This refers to how much time you want to dedicate to maintaining/unkeeping your yard. If you don’t want to spend a lot of time with upkeep, then you will want to aim for a low maintenance design. (low maintenance plants and features)*

> We do have free time but want to plan around low maintenance.  There are no watering systems but there is plenty of rain.  Currently there is an abundance of lawn.  We want to reduce the amount of lawn.  Using large islands we hope to break up the lawn so there is minimal, possibly zero mowing necessary.
> Besides ocassional breaks in life, maximum once per week, and at least once per month we would like to do some garden work.
> During the winter there should be no garden work.

5.  What USDA hardiness Zone is your site in? *(relevant for landscaping/plantings, not necessarily hardscaping/planning stages)*

> 5a

6.  What is the sun exposure? Full sun, partial sun or filtered light, part shade, full shade on my property? (can be indicated on a map/diagram for plantings)

>> K has a weird plan fro this - but E is starting to do this empirically.  Does not need to be daily.  Walk around the house.  This might be easy to answer with a birds eye view of the house.  This might not change that much throughout the year

> See sun exposure

7.  Understanding soil factors.  Drainage characteristics, ph levels, texture (sandy, clay, loamy), compaction level, soil toxicity, evidence of recent construction or soil layer disturbance, erosion level.  Are we going to need to liven up the soil.  Is the soil sandy enough, too silty.  Drainage - saturate then squeeze a fistfull of soil.  For ph - just use the pH test strips - R will look into how to do this.  Should be sandy, or clay or silt in the spectrum.

> yes
> see Soil Stuff

8.  Are there above ground structural factors to be concerned with for exterior landscape? Proximity to surrounding buildings or structures, overhead wire height, utilities.  Are there limitations to below-ground space? (gas/water lines/septic tank, idk)

>> Trees might be considered, check into local regulation on easements.  I will call in to get this info, find out what our limitations are, also locate them on our property.

> There are no overhead utilities.  Power and communications are burried and located on the north side edge of the property and brought to the domicile underground.  A main sewer pipe extends from the middle of the house diagonally towards the street adjacent corner of the property.  These things will be mapped onto a planning document.

9. How to phase the construction of my garden? *install hardscape before plantings. Paths, patios, fences, and retaining-walls are the bones of the garden. Hardscape first, along with irrigation, lighting, and permanent elements*

> this seems difficult to answer

## some other notes
like boulders whateva
Work with you with our list of interests.
Prep Yard for Work
Have a map of yard - 
know your property lines, 
know where your underground lines are (water/gas/whatever)
Trees on your property, hot/dry spots on property, know what spots get how much sunlight (helps with understanding your microclimates, determines where certain plants will thrive)
prime yard and clear unwanted plants/weeds/grass/hardscape feature

## overhead view
Birds eye view of property with buildings, trees, street, and other paved areas marked off.

![overhead view](images/thumbs/overhead-basic.png)

[full size](images/overhead-basic.png)


## soggy lawn issue
Possible reasons for soggy - 
Low-lying areas that gather rainwater
Soil that retains too much moisture (might be silty/claylike, well draining aims for 1:1:1 silt sand clay)
Blocked drainage lines or grates
Landscape features that impede water drainage (in this case, possible slope from road/walkway?) 
Solutions for soggy - 

For low areas: the quickest solution is to build up the area with a dirt and gravel combination that allows drainage, packs firm, and stops water from collecting.
High water retention: till up the yard and mix sand into the top six or eight inches of the existing soil. Either reseed section or make plantings after
For clogged drain: remove debris , especially before a heavy rainstorm and directly after one so water won’t accumulate in your yard.
The [French drain](https://en.wikipedia.org/wiki/French_drain) solution is a relatively quick and inexpensive way to drain water from problem areas in your muddy yard.
If you have a wet location in your yard, look around to see if any landscape feature is preventing water from flowing (slope?). If so, remove the feature or dig a trench and install drain pipes to wick the water away from that problem area.
Plant rain garden over mushy area or retaining wall plantings can help control erosion and control the water

Other possible solution but probably not too effective for this case : 
Aeration  - poke holes, allow air in soil either manually or with machine
Regrade entire yard

## squeeze test
Grab a handful of soil and softly compress it in your fist.
* If the soil is sticky and slick to the touch and remains intact and in the same shape when you let go, it will be clay soil.
* If the soil feels spongy it’s peaty soil; sandy soil will feel gritty and crumble apart.
* Loamy and silty soils will feel smooth textured and hold their shape for a short period of time.

## acidity nitrogen phosorous test
Acidity/NitrogenPhosorousK test
Video - Soil Testing: How to Collect Soil Samples at Home
What you will need:
*  Sample core tool or garden spade
*  Clean bucket/container to hold your sample cores
*  A zip-lock bag (labeled per section)


Soil nutrients and PH are determined by the composition of the soil and what grows in the soil. The soil nutrients and ph levels may differ around the various sections of your yard. Important to collect soil from the different sections of your garden and to test them separately. 
Examples of possible sections:
*  the lawn is one section
*  a garden bed is a section
*  the area under or around shrubs/trees is another section. 
*take more than one sample for each section*

Once you determine the sections you will be testing and where you would like to pull from, clear the organic material from the surface of the soil so that the top of the soil is visible. The organic material might be grass, mulch, rocks, etc. 

Depth of sample
*  Lawn & Landscaping - 4-5 inches
*  Home Gardens - 6-7 inches
*  Large fruit trees - 6-7 inches

Width/diameter of sample
*  about at inch is sufficient 
*  The width should be the same throughout the sample to get the most accurate results. The soil nutrient level is highest near the surface and depletes as depth increases. If the sample is thicker where the soil is more nutritious then the results will overstate your soils nutrients. 


Combine the section’s samples in the clean bucket/container and mix them together. Remove large rocks or objects in the soil. Dump a small amount of soil, about a teaspoon, into a clean ziplock bag and add distilled water.  The mixture should be soggier than mud, but without so much water that all the soil settles to the bottom quickly -- usually about twice as much water as soil works well. Stir or shake the mixture to evenly distribute the soil.

Dipping the end of the litmus paper into your soil and water mixture starts the acidic reaction in the paper. Hold it in the mixture for 1 or 2 seconds before pulling it out, and then wait a few seconds until the color stabilizes. If you have a litmus paper kit designed for pH testing, compare the color to the condensed chart included with the paper. With standard litmus paper, look for one of two color options. If the paper turns red, you have acidic soil. When blue appears, the pH is more alkaline.

![kit on amazon](images/thumbs/nutrient-test-kit.jpg)

[full size](images/nutrient-test-kit.jpg)

## composting
## native plants
replace lawn
## garden beds
culverts
## retaining walls
## vegetable garden
## chinese style greenhouses
## rainwater harvesting
## riprap infiltration pit rain garden
## worms
## arborist
inspect vertical cracks in bark

## instructions
Project management usually involves different views that allow one to dynamically change scope to prvent infomration overload.  Unfortunatley we are not sophisticated enough to do that.  Here we start with an outline.  Currently we have two lists, `Important`, and `Wants`.  The `Important` list contains goals defined by the project manager.  The `Wants` list contains ideas from either the client or project manager.  These lists are located just after the main heading, `Landscape Plans` and are immediately followed by two headings, `Completed Projects`, and `In Progress`.  Individual goals are detailed in either `Completed Projects` or `In Progress`.  These goals are referenced in either project manager's list, `Important`, or the clients list, `Wants`.  Client goals that are being worked on are moved into the `Important` list.
